@@ -17,7 +17,7 @@ class Usage(GitflowError):
 class OperationsError(GitflowError): pass
 class PrefixNotUniqueError(OperationsError): pass
 class MergeError(OperationsError): pass
-
+class PostReviewError(OperationsError): pass
 
 class StatusError(GitflowError): pass
 class WorkdirIsDirtyError(StatusError): pass
@@ -43,6 +43,9 @@ class MergeConflict(StatusError):
 
 class EmptyDiff(StatusError): pass
 
+class InconsistencyDetected(StatusError):
+    def __str__(self):
+        return "Inconsistency detected: {0}".format(self.args[0])
 
 class ObjectError(GitflowError): pass
 class BadObjectError(ObjectError): pass
